##  Scope
Currently, the integration supports the following:
  * SaaS products and SaaS ERP entries
  * SAP Private Cloud products and SAP Private Cloud ERP entries
  * SAP On-Premise products, including ERP systems
  * SAP system information
  * Integration flows between SAP systems detected through SAP Cloud ALM Integration & Exception Monitoring
For more information, see [Enabling Discovered Flows](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows?locale=en-US&state=PRODUCTION&version=CLOUD "Discovered flows in SAP Cloud ALM enable automatic identification and visualization of real integration flows between SAP systems, supporting integration mapping, dependency analysis, and interface documentation. This feature helps organizations gain visibility into active system communications and streamline interface management.").
